[−][src]Module libmtp_rs::error
This module contains information about possible errors, such as internal and libmtp errors.
Enums
| Error | Main Error type, containing a possible unknown error, an specific |
| MtpErrorKind | Enumeration of possible |
This module contains information about possible errors, such as internal and libmtp errors.
| Error | Main Error type, containing a possible unknown error, an specific |
| MtpErrorKind | Enumeration of possible |