[−][src]Enum libmtp_rs::util::HandlerReturn
Must return type of send and getter handlers that deal with raw bytes.
Variants
Return this if every went ok.
Return this if there was an error.
Return this if you want to cancel the operation earlier.