[−][src]Module libmtp_rs::values
This module contains items used to determine which values are allowed to be used on certain object attributes (aka properties).
Structs
| AllowedValues | Contains the allowed values of an specific attribute, determines which data type should be used, and if the values are a range or enumeration. |
| Values | Contains relevant information about the allowed values for an specific type |
Enums
| DataType | Enumeration to determine the data type of the allowed values. |